@@ -18,11 +18,17 @@
 import pyparticles.animation.test_animation as tt
 
 def test( ty ):
+    """
+    testing procedures
     
+    ty: test name
+    """
     if ty == "fall":
         tst = tt.TestAnimation()
     elif ty == "harmonic" :
-        tst = tt.TestAnimationArmonic()
+        tst = tt.TestAnimationHarmonic()
+    elif ty == "dharmonic" :
+        tst = tt.TestAnimationDampedHarmonic()
         
     tst.build_animation()
     tst.start()
\ No newline at end of file
